.. image:: https://img.shields.io/pypi/v/bioblend.svg
    :target: https://pypi.org/project/bioblend/
    :alt: latest version available on PyPI

.. image:: https://readthedocs.org/projects/bioblend/badge/
    :alt: Documentation Status
    :target: https://bioblend.readthedocs.io/

.. image:: https://badges.gitter.im/galaxyproject/bioblend.svg
   :alt: Join the chat at https://gitter.im/galaxyproject/bioblend
   :target: https://gitter.im/galaxyproject/bioblend?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge


BioBlend is a Python library for interacting with the `Galaxy`_ API.

BioBlend is supported and tested on:

- Python 3.8 - 3.12
- Galaxy release 19.05 and later.

Full docs are available at https://bioblend.readthedocs.io/ with a quick library
overview also available in `ABOUT.rst <./ABOUT.rst>`_.

.. References/hyperlinks used above
.. _Galaxy: https://galaxyproject.org/
